@@ -1,15 +1,13 @@
-from abc import ABCMeta
+from abc import ABC
 from typing import TYPE_CHECKING
 
-import six
-
 
 if TYPE_CHECKING:
     from explicit.contrib.adapters.messaging.kafka import Adapter
     from explicit.messagebus import MessageBus
 
 
-class IConfig(six.with_metaclass(ABCMeta, object)):
+class IConfig(ABC):
     """Конфигурация модуля управления доступом на основе ролей."""
 
     bus: 'MessageBus'
